static const char context_string_value[] =
 "# configured Tue May 24 18:34:35 EDT 2005\n"
 "sh ./configure \n"
 "\n"
 "Context:\n"
 "\n"
 "[update web page to reflect new stable release (1.0.3)\n"
 "Tomasz Zielonka <tomasz.zielonka@gmail.com>**20050524225643] \n"
 "\n"
 "[TAG 1.0.3\n"
 "Tomasz Zielonka <tomasz.zielonka@gmail.com>**20050524215127] \n"
 "";
char *context_string(void) {
  return (char *) context_string_value;
}
